function HUDLoadingScreen:_layout_raid(current_job)
	local info_panel_params = {
		alpha = 0,
		name = "info_panel",
		x = self._panel:w() / 2 - HUDLoadingScreen.RAID_INFO_W / 2,
		y = HUDLoadingScreen.RAID_INFO_Y,
		w = HUDLoadingScreen.RAID_INFO_W,
		h = HUDLoadingScreen.RAID_INFO_H,
		layer = self._bg:layer() + 1
	}
	self._info_panel = self._panel:panel(info_panel_params)
	local raid_title_panel_params = {
		name = "raid_title_panel",
		h = HUDLoadingScreen.INFO_TITLE_H,
		layer = self._info_panel:layer() + 1
	}
	local raid_title_panel = self._info_panel:panel(raid_title_panel_params)

	raid_title_panel:set_center_y(HUDLoadingScreen.RAID_INFO_TITLE_CENTER_Y)

	local raid_icon_params = {
		name = "raid_icon",
		y = 0,
		x = 0,
		texture = tweak_data.gui.icons[current_job.icon_menu].texture,
		texture_rect = tweak_data.gui.icons[current_job.icon_menu].texture_rect
	}
	local raid_icon = raid_title_panel:bitmap(raid_icon_params)

	raid_icon:set_center_y(raid_title_panel:h() / 2)

	local raid_title_params = {
		name = "raid_title",
		vertical = "center",
		align = "center",
		x = raid_icon:w() + HUDLoadingScreen.MISSION_ICON_PADDING_RIGHT,
		h = raid_title_panel:h(),
		font = tweak_data.gui:get_font_path(HUDLoadingScreen.INFO_TITLE_FONT, HUDLoadingScreen.INFO_TITLE_FONT_SIZE),
		font_size = HUDLoadingScreen.INFO_TITLE_FONT_SIZE,
		color = HUDLoadingScreen.INFO_TITLE_COLOR,
		text = utf8.to_upper(managers.localization:text(current_job.name_id))
	}
	local title = raid_title_panel:text(raid_title_params)
	local _, _, w, _ = title:text_rect()

	title:set_w(w)
	raid_title_panel:set_w(title:x() + title:w())
	raid_title_panel:set_center_x(self._info_panel:w() / 2)

	local difficulty_params = {
		amount = tweak_data:number_of_difficulties()
	}
	local difficulty_indicator = RaidGuiControlDifficultyStars:new(self._info_panel, difficulty_params)

	difficulty_indicator:set_center_x(self._info_panel:w() / 2)
	difficulty_indicator:set_center_y(HUDLoadingScreen.RAID_DIFFICULTY_CENTER_Y)

	local current_difficulty = tweak_data:difficulty_to_index(Global.game_settings.difficulty)

	difficulty_indicator:set_active_difficulty(current_difficulty)

	local raid_description_params = {
		name = "raid_description",
		vertical = "top",
		wrap = true,
		align = "center",
		y = HUDLoadingScreen.RAID_INFO_TEXT_Y - 20,
		h = self._info_panel:h() - HUDLoadingScreen.RAID_INFO_TEXT_Y + 300,
		font = tweak_data.gui:get_font_path(HUDLoadingScreen.RAID_INFO_TEXT_FONT, HUDLoadingScreen.RAID_INFO_TEXT_FONT_SIZE),
		font_size = HUDLoadingScreen.RAID_INFO_TEXT_FONT_SIZE,
		color = HUDLoadingScreen.RAID_INFO_TEXT_COLOR,
		text = managers.localization:text(current_job.loading.text) .. "\n" .. self:_get_random_tip()
	}
	local description = self._info_panel:text(raid_description_params)
end

function HUDLoadingScreen:_layout_operation(current_job)
	local info_panel_params = {
		alpha = 0,
		name = "info_panel",
		x = self._panel:w() / 2 - HUDLoadingScreen.OPERATION_INFO_W / 2,
		y = HUDLoadingScreen.OPERATION_INFO_Y,
		w = HUDLoadingScreen.OPERATION_INFO_W,
		h = HUDLoadingScreen.OPERATION_INFO_H,
		layer = self._bg:layer() + 1
	}
	self._info_panel = self._panel:panel(info_panel_params)
	local operation_title_panel_params = {
		name = "raid_title_panel",
		y = HUDLoadingScreen.INFO_TITLE_Y,
		h = HUDLoadingScreen.INFO_TITLE_H,
		layer = self._info_panel:layer() + 1
	}
	local operation_title_panel = self._info_panel:panel(operation_title_panel_params)
	local operation_icon_params = {
		name = "operation_icon",
		y = 0,
		x = 0,
		texture = tweak_data.gui.icons[current_job.operation_icon].texture,
		texture_rect = tweak_data.gui.icons[current_job.operation_icon].texture_rect
	}
	local operation_icon = operation_title_panel:bitmap(operation_icon_params)

	operation_icon:set_center_y(operation_title_panel:h() / 2)

	local operation_title_params = {
		name = "operation_title",
		vertical = "center",
		align = "center",
		x = operation_icon:w() + HUDLoadingScreen.MISSION_ICON_PADDING_RIGHT,
		h = operation_title_panel:h(),
		font = tweak_data.gui:get_font_path(HUDLoadingScreen.INFO_TITLE_FONT, HUDLoadingScreen.INFO_TITLE_FONT_SIZE),
		font_size = HUDLoadingScreen.INFO_TITLE_FONT_SIZE,
		color = HUDLoadingScreen.INFO_TITLE_COLOR,
		text = utf8.to_upper(managers.localization:text(current_job.operation_name_id) .. " " .. tostring(current_job.current_event) .. "/" .. tostring(current_job.number_of_events))
	}
	local title = operation_title_panel:text(operation_title_params)
	local _, _, w, _ = title:text_rect()

	title:set_w(w)
	operation_title_panel:set_w(title:x() + title:w())
	operation_title_panel:set_center_x(self._info_panel:w() / 2)

	local event_title_params = {
		name = "current_event_title",
		vertical = "center",
		align = "center",
		y = HUDLoadingScreen.OPERATION_EVENT_TITLE_Y,
		h = HUDLoadingScreen.OPERATION_EVENT_TITLE_H,
		font = tweak_data.gui:get_font_path(HUDLoadingScreen.OPERATION_EVENT_TITLE_FONT, HUDLoadingScreen.OPERATION_EVENT_TITLE_FONT_SIZE),
		font_size = HUDLoadingScreen.OPERATION_EVENT_TITLE_FONT_SIZE,
		color = HUDLoadingScreen.OPERATION_EVENT_TITLE_COLOR,
		text = utf8.to_upper(managers.localization:text(current_job.progress_title_id))
	}
	local title = self._info_panel:text(event_title_params)
	local _, _, w, _ = title:text_rect()

	title:set_w(w)
	title:set_center_x(self._info_panel:w() / 2)

	local difficulty_params = {
		amount = tweak_data:number_of_difficulties()
	}
	local difficulty_indicator = RaidGuiControlDifficultyStars:new(self._info_panel, difficulty_params)

	difficulty_indicator:set_center_x(self._info_panel:w() / 2)
	difficulty_indicator:set_center_y(HUDLoadingScreen.OPERATION_DIFFICULTY_CENTER_Y)

	local current_difficulty = tweak_data:difficulty_to_index(Global.game_settings.difficulty)

	difficulty_indicator:set_active_difficulty(current_difficulty)

	local event_description_params = {
		name = "raid_description",
		vertical = "top",
		wrap = true,
		align = "center",
		y = HUDLoadingScreen.OPERATION_INFO_TEXT_Y,
		h = self._info_panel:h() - HUDLoadingScreen.OPERATION_INFO_TEXT_Y,
		font = tweak_data.gui:get_font_path(HUDLoadingScreen.OPERATION_INFO_TEXT_FONT, HUDLoadingScreen.OPERATION_INFO_TEXT_FONT_SIZE),
		font_size = HUDLoadingScreen.OPERATION_INFO_TEXT_FONT_SIZE,
		color = HUDLoadingScreen.OPERATION_INFO_TEXT_COLOR,
		text = managers.localization:text(current_job.loading.text) .. "\n" .. self:_get_random_tip()
	}
	local description = self._info_panel:text(event_description_params)
end
